pub fn http_date_epoch_seconds(time: SystemTime) -> i128Expand description
Returns whole seconds relative to the Unix epoch, preserving pre-epoch ordering.
pub fn http_date_epoch_seconds(time: SystemTime) -> i128Returns whole seconds relative to the Unix epoch, preserving pre-epoch ordering.