validate_http_date

Function validate_http_date 

pub fn validate_http_date(time: SystemTime) -> Result<(), HttpValidatorError>
Validates that a system time is representable as an HTTP date without formatting it.

Errors

Returns HttpValidatorError::InvalidHttpDate for times before the Unix epoch or after the maximum date supported by the HTTP-date representation.