pub enum UniqueUuidAttempt<T> {
Accepted(T),
Collision,
}Expand description
Result of attempting to reserve or accept a generated UUID.
Variants
Accepted(T)
Candidate was accepted and produced a value.
Collision
Candidate collided and should be retried with a new UUID.