bytes_to_usize

Function bytes_to_usize 

pub fn bytes_to_usize(bytes: i64, value_name: &str) -> Result<usize>
Converts a signed byte count to usize.

Errors

Returns an error when bytes is negative or does not fit in usize on the current platform.