pub fn normalize_path(path: &Path) -> PathBufExpand description
Normalizes a path lexically without touching the filesystem.
. components are dropped. .. removes the previous normal component when possible, but it is
preserved when removing it would cross an unknown relative root. Absolute roots and platform
prefixes are retained.